==> dde-session-shell_5.5.14.orig.tar.xz: dde-session-shell-5.5.14/translations/dde-session-shell_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>面容</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>請驗證人臉ID</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>人臉ID已鎖定，請輸入密碼</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>請驗證指紋</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>指紋已鎖定，請輸入密碼</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>請1分鐘後再試</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>虹膜</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>請驗證虹膜ID</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>虹膜ID已鎖定，請輸入密碼</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>密碼錯誤</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>請輸入密碼</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>請1分鐘後再試</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>重設密碼</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>忘記密碼？</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>請1分鐘後再試</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>重設密碼</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>忘記密碼？</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN錯誤</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>需要使用UKEY認證</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>識別到UKEY，需要輸入PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>請1分鐘後再試</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>帳戶</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>密碼將於%n天後過期，請及時修改密碼</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>密碼已過期，請修改</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>帳戶錯誤</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>密碼錯誤</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>鎖定螢幕</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>無法鎖定螢幕</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>指紋驗證逾時，請手動輸入密碼</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>無法進行指紋配對</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>以上的使用者仍在登入，且關機後這些使用者的資料將會遺失。確定關機？</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>以上的使用者仍在登入，且重開機後這些使用者的資料將會遺失。確定重啟？</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>您已開啟進階別等級保護，無法切換Wayland模式，請於“安全中心”關閉進階別等級保護後再試</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>登出</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>切換使用者</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>切換系統</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>啟動系統監視器</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>這些程式導致電腦不能關機。強制關機可能會導致資料遺失。</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>如要關閉程式，請按下「取消」後關閉程式。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>這些程式導致電腦不能重新開機。強制重新開機可能會導致資料遺失。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>這些程式導致電腦不能待機。強制待機可能會導致資料遺失。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>這些程式導致電腦不能休眠。強制休眠可能會導致資料遺失。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>這些程式導致電腦不能登出。強制登出可能會導致資料遺失。</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>登出</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>確定關機？</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>確定重開機？</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>確定登出？</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>關閉</translation>
    </message>
</context>
</TS>

==> dde-session-shell_6.0.3.orig.tar.xz: dde-session-shell-6.0.3/translations/dde-session-shell_zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>面容</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>請驗證人臉ID</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>人臉ID已鎖定，請輸入密碼</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>設備不可用！</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>請驗證指紋</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>指紋已鎖定，請輸入密碼</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>虹膜</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>請驗證虹膜ID</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>虹膜ID已鎖定，請輸入密碼</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>密碼錯誤</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>請輸入密碼</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>請1分鐘後再試</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>重設密碼</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>忘記密碼？</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>請1分鐘後再試</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>重設密碼</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>忘記密碼？</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>驗證成功</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>驗證失敗，您還可以嘗試%n次</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>驗證失敗，您還可以嘗試1次</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>PIN錯誤</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>需要使用UKEY認證</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>識別到UKEY，需要輸入PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>請1分鐘後再試</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>請%n分鐘後再試</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>帳戶</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>密碼將於%n天後過期，請及時修改密碼</numerusform></translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it.</source>
        <translation>您的密碼已過期，請聯絡管理員修改密碼</translation>
    </message>
    <message>
        <source>Your password has expired. Please change it.</source>
        <translation>密碼已過期，請修改</translation>
    </message>
</context>
<context>
    <name>ChangePasswordWidget</name>
    <message>
        <source>Your password has expired. Please change it and log in again.</source>
        <translation>您的密碼已過期，請修改密碼後重新登入</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>儲 存</translation>
    </message>
    <message>
        <source>Old password</source>
        <translation>舊密碼</translation>
    </message>
    <message>
        <source>New password</source>
        <translation>新密碼</translation>
    </message>
    <message>
        <source>Repeat new password</source>
        <translation>重複新密碼</translation>
    </message>
    <message>
        <source>Password hint (Optional)</source>
        <translation>密碼提示（選填）</translation>
    </message>
    <message>
        <source>Passwords do not match</source>
        <translation>密碼不一致</translation>
    </message>
    <message>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation>密碼提示對所有人可見，切勿包含具體密碼訊息</translation>
    </message>
    <message>
        <source>New password should differ from the current one</source>
        <translation>新的密碼必須不同於目前密碼</translation>
    </message>
    <message>
        <source>Password changed</source>
        <translation>修改密碼成功</translation>
    </message>
    <message>
        <source>Wrong password</source>
        <translation>密碼錯誤</translation>
    </message>
</context>
<context>
    <name>ControlWidget</name>
    <message>
        <source>Desktop Environment and Display Protocol</source>
        <translation>桌面環境與顯示協議</translation>
    </message>
    <message>
        <source>Keyboard Layout</source>
        <translation>鍵盤佈局</translation>
    </message>
    <message>
        <source>Switch User</source>
        <translation>切換使用者</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>電源</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>帳戶錯誤</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>密碼錯誤</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>鎖定螢幕</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>無法鎖定螢幕</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>指紋驗證逾時，請手動輸入密碼</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>無法進行指紋配對</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>以上的使用者仍在登入，且關機後這些使用者的資料將會遺失。確定關機？</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>以上的使用者仍在登入，且重開機後這些使用者的資料將會遺失。確定重啟？</translation>
    </message>
</context>
<context>
    <name>PasswordLevelWidget</name>
    <message>
        <source>Weak</source>
        <translation>強度低</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>強度中</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>強度高</translation>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <source>Password cannot be empty</source>
        <translation>密碼不能空白</translation>
    </message>
    <message>
        <source>Password must have at least %1 characters</source>
        <translation>密碼應包含至少%1個字元</translation>
    </message>
    <message>
        <source>Password must be no more than %1 characters</source>
        <translation>密碼必須少於 %1 個字元</translation>
    </message>
    <message>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>密碼只能由英文（區分大小寫）、數字或特殊符號（~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/）組成</translation>
    </message>
    <message>
        <source>No more than %1 palindrome characters please</source>
        <translation>回文字元長度不超過%1位</translation>
    </message>
    <message>
        <source>No more than %1 monotonic characters please</source>
        <translation>單調性字元不超過%1位</translation>
    </message>
    <message>
        <source>No more than %1 repeating characters please</source>
        <translation>重複字元不超過%1位</translation>
    </message>
    <message>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>密碼必須由大寫字母、小寫字母、數字、符號（~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/）三種類型組成</translation>
    </message>
    <message>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation>密碼不得含有連續4個以上的回文字符</translation>
    </message>
    <message>
        <source>Do not use common words and combinations as password</source>
        <translation>密碼不能是常見單詞及組合</translation>
    </message>
    <message>
        <source>Create a strong password please</source>
        <translation>密碼過於簡單，請增加密碼複雜度</translation>
    </message>
    <message>
        <source>It does not meet password rules</source>
        <translation>密碼不符合安全要求</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>鎖定</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>登出</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>切換系統</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>切換使用者</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>啟動系統監視器</translation>
    </message>
</context>
<context>
    <name>UserListPopupWidget</name>
    <message>
        <source>Standard User</source>
        <translation>標準使用者</translation>
    </message>
    <message>
        <source>Administrator</source>
        <translation>管理員</translation>
    </message>
    <message>
        <source>Other Users</source>
        <translation>其他使用者</translation>
    </message>
</context>
<context>
    <name>VirtualKeyboardModule</name>
    <message>
        <source>Onboard</source>
        <translation>螢幕鍵盤</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>這些程式導致電腦不能關機。強制關機可能會導致資料遺失。</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>如要關閉程式，請按下「取消」後關閉程式。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>這些程式導致電腦不能重新開機。強制重新開機可能會導致資料遺失。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>這些程式導致電腦不能待機。強制待機可能會導致資料遺失。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>這些程式導致電腦不能休眠。強制休眠可能會導致資料遺失。</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>這些程式導致電腦不能登出。強制登出可能會導致資料遺失。</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>關機</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重新啟動</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>待機</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>登出</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>確定關機？</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>確定重開機？</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>確定登出？</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>開啟</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>關閉</translation>
    </message>
</context>
</TS>
